Changelog
=========

2.3.2 (2015-05-04)
------------------

- Fix wrong closing tag in subpageform.pt
  [vincentfretin]

- Fix checkbox widget rendering so non-ASCII translations can be used.
  [terapyon]


2.3.1 (2014-10-23)
------------------

- Remove Products.PloneTestCase dependency. This closes `#241`_.
  [ericof]


2.3.0 (2014-02-26)
------------------

- Remove DL's from portal message in templates.
  https://github.com/plone/Products.CMFPlone/issues/153
  [khink]

- Move date_components_support view to Products.Archetypes.
  [davisagli]


2.2.4 (unreleased)
------------------

- Fixed ValueError in DateComponents.result() with a date before 1900.
  [bsuttor]


2.2.3 (2013-08-13)
------------------

- Decode form data prior to inline validation.
  This fixes https://dev.plone.org/ticket/13639
  [davisagli]


2.2.2 (2013-03-05)
------------------

- Fixed TypeError in DateComponents.resault()
  [yangh]


2.2.1 (2013-01-01)
------------------

- Finish removing KSS-based inline editing support.
  [davisagli]


2.2.0 (2012-10-16)
------------------

- Switch to a non-KSS-based implementation of inline validation.
  [davisagli]


2.1.2 (2012-08-29)
------------------

- Fix handling of timezones for dates before 1970 on platforms where
  time.localtime cannot handle negative values (such as Windows).
  [mj]

2.1.1 (2012-08-04)
------------------

- Customize formlib sequencewidget in order to add originalValue attribute.
  We need it to enable form unload protection for list fields on Plone forms.
  [vipod]

2.1 (2012-05-25)
----------------

- Remove hard-coded required markers. Replaced by CSS in Plone 4.2.x.
  [smcmahon]

- Depend on zope.formlib rather than zope.app.form.
  [davisagli]

2.0.5 (2012-01-26)
------------------

- Fix the CheckBoxWidget to work properly with required fields and
  return an error that was previously squashed. Added missing unit tests
  for widget. This should also fix #11449. [rochecompaan]

2.0.4 - 2011-10-06
------------------

- Added support for readonly, addonly and removeonly to multi USW.
  Warning! Readonly is implemented in code, but addonly and removeonly is
  only done in the UI!
  [fschulze, tesdal]

- Added overrides for IPageForm and ISubPageForm as the monkeypatch
  breaks compatibility with five.formlib without restoring it in
  any other way if we don't import from plone.app.form.
  [tesdal]

2.0.3 - 2011-07-13
------------------

- Made (more) compatible with chameleon by using a simpler way to get
  the wysiwyg editor.
  [maurits]

- Add MANIFEST.in.
  [WouterVH]


2.0.2 - 2011-02-04
------------------

- Stop stripping GMT when passed to widget display and replace dates
  that have "-" with "/" so the proper timezone is applied. See #11423
  [eleddy]

- Fix edge case of dates that are greater than the last minute interval.
  Now rounding down to last interval instead of returning "--".
  [eleddy]


2.0.1 - 2011-01-03
------------------

- Use the FileUploadWidget from CMFDefault as the default widget for the
  FileUpload field from the same package (this was lost when CMFPlone
  started excluding CMFDefault's ZCML.)
  [davisagli]


2.0 - 2010-07-18
----------------

- Update license to GPL version 2 only.
  [hannosch]


2.0b6 - 2010-06-13
------------------

- Avoid deprecation warnings under Zope 2.13.
  [hannosch]

- Use the standard libraries doctest module.
  [hannosch]

- Explicitly load CMFCore's permissions and five.formlib ZCML.
  [hannosch]

- Updated to use five.formlib.
  [hannosch]

- Remove tabindex deprecated html attribute.
  [edegoute]


2.0b5 - 2010-04-10
------------------

- Make the date components view always represent the date in the local
  timezone.
  [davisagli]


2.0b4 - 2010-04-08
------------------

- Make sure that named template adapters use Chameleon-compatible templates
  if five.pt is present.  Closes http://dev.plone.org/plone/ticket/10103.
  [davisagli]

- Replace the required field indicator image with a unicode box.
  Refs http://dev.plone.org/plone/ticket/10352
  [davisagli, limi]


2.0b3 - 2010-03-05
------------------

- Decode form inputs before trying to do inline validation of them, the same
  way they would be in a real form submission. This closes
  http://dev.plone.org/plone/ticket/9757.
  [davisagli]

- Use the search text input as the target for the uberselection widget label.
  Fixes invalid HTML.
  [rossp]

- Fix invalid HTML by moving the xmlns declarations into a tag that will be
  omitted by TAL.
  [rossp]


2.0b2 - 2010-02-17
------------------

- Updated pageform.pt to follow recent markup conventions.
  References http://dev.plone.org/plone/ticket/9981.
  [spliter]

- Fixed macro call in add form page template.
  [do3cc]


2.0b1 - 2009-12-27
------------------

- Fixed package dependency declaration.
  [hannosch]


2.0a2 - 2009-12-02
------------------

- Updated the LanguageDropdownChoiceWidget to present its options sorted by
  the localized title. So far it showed localized titles while keeping
  English ordering.
  [hannosch]


2.0a1 - 2009-11-14
------------------

- Made sure to use the correct ViewPageTemplateFile from Products.Five.
  [hannosch]

- Updated to use new locations for IAdding and IObjectEvent.
  [hannosch]

- Updated checkboxwidget hacks to work with zope.app.form 3.8.0.
  [hannosch]

- Use getSite from zope.site instead of zope.app.component.
  [hannosch]

- Made sure tests don't rely on kupu.
  [hannosch]

- Updated import of ITerms to zope.browser.interfaces.
  [hannosch]

- Made kss support truly optional and advertise it via an extra.
  [hannosch]

- Use our own PloneMessageFactory. We don't depend on CMFPlone anymore.
  [hannosch]

- Specified package dependencies.
  [hannosch]

- Corrected the NamedTemplateAdapter to work with the modified
  ViewPageTemplateFile in Zope 2.12.
  [davisagli]


1.1.9 - Unreleased
------------------

- Fixed some duplicated msgids with different defaults.
  There is no new strings to translate.
  See http://dev.plone.org/plone/ticket/9633
  [vincentfretin]


1.1.8 - 2009-10-09
------------------

- Made default truncation size of 20 results on the uberselectionwidget
  configurable by a simple variable called `limit_results` on the widget.
  [hannosch]

- Fixed return value of multi selection widget _value method. The template
  tries to get len() of the value, but fails if the value is None. This allows
  to use multi selection widget in the portlets, for example.
  [naro]


1.1.7 - 2008-03-07
------------------

- Fixed inline save of 'title' field raises 'Invalid request' error.
  This closes http://dev.plone.org/plone/ticket/8189.
  [deo]


1.1.6 - 2008-11-21
------------------

- Made a test less dependent on the exact HTML output, so it works across
  Zope versions with slightly different newline ending semantics.
  [hannosch]

- Only include KSS subpackage if kss.core is available.
  [hannosch]

- Fixed KSS payload tests to omit a trailing newline.
  [hannosch]

- Use structure for errors again, this seems to have been lost in the merge
  of r19540.
  [elro]


1.1.5 - 2008-08-18
------------------

- Add a MultiCheckBoxWidget that uses <label>s to be accessible.
  [csenger]

- Forced the input values of the datecomponents into integers before doing
  calculations with them. This closes
  http://dev.plone.org/plone/ticket/6737.
  [hannosch]

- Synchronized the default value behavior of all fields in the datetime
  widget. This closes http://dev.plone.org/plone/ticket/6988.
  [hannosch]


1.1.0 - 2008-04-20
------------------

- Changed the patch warning to debug level. This is nothing the end users have
  to see.
  [hannosch]


1.1.0a1 - 2008-03-09
--------------------

- Improve KSS inline validation for complex widgets like the UberSelectionwidget
  that require more than a single form value to validate.
  [optilude]

- PLIP202: add support for KSS validation and inline editing for formlib forms.
  [optilude]


1.0.5
-----

- For the USW:
  Made description of search result and current selection items
  consistent, always include the current selection fieldset (hidden if
  empty) and added CSS classes to the current selection and search result
  fieldsets.
  [fschulze]

- Fix widget error rendering in template (added structure keyword).
  [ldr]


1.0.4 - 2007-12-06
------------------

- Omit first label tag completely instead of having an empty one for
  checkboxes.
  [fschulze]

- Added id to wrapping div of the field for easy access for styles and
  javascripts, the form is 'field-$fieldname'.
  [fschulze]


1.0.3 - 2007-11-09
------------------

- Changed template to render info messages as infos and error messages as
  errors, instead of all messages (info and error both) as errors.
  [derek_richardson]

- Protect against funky aq_chains.
  [hannosch, rafrombrc]


1.0.2 - 2007-10-08
------------------

- Fixed fall back to language name in LanguageDropdownChoiceWidget.
  [hannosch]

- Added i18n markup to the formlib base templates, so the required message
  will be translated the same way as in the rest of Plone. This closes
  http://dev.plone.org/plone/ticket/7063.
  [hannosch]


1.0.1
-----

- Add a form validator that only validates an action when updating a
  form. This makes it possible to add actions manually in the template
  without having formlib autogenerate buttons in other places.
  [wichert]


1.0 - 2007-08-17
----------------

- Let the UberSelectionWidget handle optional fields properly.
  [optilude]

- Added a new LanguageDropdownChoiceWidget, which renders a dropdown widget
  which is populated by a language vocabulary. The language names are then
  localized based on the zope.i18n.locales information.
  [hannosch]

- Added a new DisabledCheckBoxWidget, which renders a disabled variant of
  the CheckBoxWidget.
  [hannosch]

- Keep existing date in the calendar widget in datecomponents.py. This
  closes http://dev.plone.org/plone/ticket/5833.
  [hannosch]


1.0b1 - 2007-03-05
------------------

- Initial implementation.
  [alecm, rocky, optilude]

- Initial package structure.
  [zopeskel]

.. _`#241`: https://github.com/plone/Products.CMFPlone/issues/241